@@ -19,7 +19,14 @@ logger = getLogger(__name__)
 
 
 class Worker:
-    def work(self, ping_host: Union[str, None] = None, ping_port: Union[int, None] = 80, log_filepath: Union[str, None] = None, debug: bool = False) -> None:
+    def work(self,
+             ping_host: Union[str,
+                              None] = None,
+             ping_port: Union[int,
+                              None] = 80,
+             log_filepath: Union[str,
+                                 None] = None,
+             debug: bool = False) -> None:
         loglevel = DEBUG if debug else INFO
         setup_logger(loglevel=loglevel, filepath=log_filepath)
         sys.path.append('.')
